@@ -12,6 +12,7 @@ import tarfile
 import warnings
 from collections import defaultdict
 import yaml
+from future.utils import raise_from
 
 # try to use LibYAML bindings if possible
 try:
@@ -45,7 +46,7 @@ Dumper.add_representer(str,
 # Display deprecation warnings
 warnings.filterwarnings("always", category=DeprecationWarning, module="hepdata_lib")
 
-__version__ = "0.4.1"
+__version__ = "0.6.0"
 
 class Variable(object):
     """A Variable is a wrapper for a list of values + some meta data."""
@@ -77,20 +78,25 @@ class Variable(object):
         if self.is_binned:
             # Check that the input is well-formed
             try:
-                assert all([len(x) == 2 for x in value_list])
-            except (AssertionError, TypeError, ValueError):
-                raise ValueError("For binned Variables, values should be tuples of length two: \
+                assert all((len(x) == 2 for x in value_list))
+            except (AssertionError, TypeError, ValueError) as err:
+                msg = "For binned Variables, values should be tuples of length two: \
                                  (lower bin edge, upper bin edge)."
-                                )
+                raise_from(ValueError(msg), err)
 
             # All good
-            self._values = [(float(x[0]), float(x[1])) for x in value_list]
+            self._values = [
+                            (
+                             helpers.sanitize_value(x[0]),
+                             helpers.sanitize_value(x[1])
+                            ) for x in value_list
+                            ]
         else:
             # Check that the input is well-formed
             try:
-                parsed_values = [x if isinstance(x, str) else float(x) for x in value_list]
-            except (TypeError, ValueError):
-                raise ValueError("Malformed input for unbinned variable: ", value_list)
+                parsed_values = [helpers.sanitize_value(x) for x in value_list]
+            except (TypeError, ValueError) as err:
+                raise_from(ValueError("Malformed input for unbinned variable: ", value_list),err)
             self._values = parsed_values
 
     def scale_values(self, factor):
@@ -161,6 +167,10 @@ class Variable(object):
 
         tmp["values"] = []
 
+        nonzero_uncs = helpers.any_uncertainties_nonzero(
+                                                        self.uncertainties,
+                                                        size=len(self._values)
+                                                        )
         for i in range(len(self._values)):
             valuedict = defaultdict(list)
 
@@ -172,25 +182,36 @@ class Variable(object):
             else:
                 valuedict["value"] = helpers.relative_round(self._values[i],
                                                             self.digits)
-
-            for unc in self.uncertainties:
-                if unc.is_symmetric:
-                    valuedict['errors'].append({
-                        "symerror":
-                            helpers.relative_round(unc.values[i], self.digits),
-                        "label":
-                            unc.label
-                    })
-                else:
-                    valuedict['errors'].append({
-                        "asymerror": {
-                            "minus":
-                                helpers.relative_round(unc.values[i][0], self.digits),
-                            "plus":
-                                helpers.relative_round(unc.values[i][1], self.digits)
-                        },
-                        "label": unc.label
-                    })
+            # An uncertainty entry is only appended
+            # if at least one of the uncertainties is not zero.
+            if nonzero_uncs[i]:
+                for unc in self.uncertainties:
+                    if unc.is_symmetric:
+                        valuedict['errors'].append({
+                            "symerror":
+                                helpers.relative_round(unc.values[i], self.digits),
+                            "label":
+                                unc.label
+                        })
+                    else:
+                        valuedict['errors'].append({
+                            "asymerror": {
+                                "minus":
+                                    helpers.relative_round(unc.values[i][0], self.digits),
+                                "plus":
+                                    helpers.relative_round(unc.values[i][1], self.digits)
+                            },
+                            "label": unc.label
+                        })
+            elif self.uncertainties:
+                print(
+                    "Warning: omitting 'errors' since all uncertainties " \
+                    "are zero for bin {} of variable '{}'.".format(i+1, self.name)
+                    )
+                print(
+                    "Note that bins with zero content should preferably " \
+                    "be omitted completely from the HEPData table."
+                    )
             tmp["values"].append(valuedict)
         return tmp
 
@@ -224,7 +245,7 @@ class Table(object):
     def name(self, name):
         """Name setter."""
         if len(name) > 64:
-            raise ValueError("Table name must not be longer than 64 characters.")
+            raise ValueError("Table name must not be longer than 64 characters: " + name)
         self._name = name
 
     def add_image(self, file_path, outdir=None):
@@ -249,6 +270,7 @@ class Table(object):
 
         if not isinstance(file_path, str):
             raise TypeError("Expected string argument, instead got: '{}'.".format(type(file_path)))
+        file_path = os.path.expanduser(file_path)
         if os.path.exists(file_path):
             self.image_files.add(file_path)
         else:
@@ -520,15 +542,13 @@ class Submission(object):
         self.copy_files(outdir)
 
         # Put everything into a tarfile
-        tar = tarfile.open("submission.tar.gz", "w:gz")
-        for yaml_file in helpers.find_all_matching(outdir, "*.yaml"):
-            tar.add(yaml_file)
-        for png_file in helpers.find_all_matching(outdir, "*.png"):
-            tar.add(png_file)
-        for additional in self.files_to_copy:
-            tar.add(os.path.join(outdir, os.path.basename(additional)))
-
-        tar.close()
+        with tarfile.open("submission.tar.gz", "w:gz") as tar:
+            for yaml_file in helpers.find_all_matching(outdir, "*.yaml"):
+                tar.add(yaml_file)
+            for png_file in helpers.find_all_matching(outdir, "*.png"):
+                tar.add(png_file)
+            for additional in self.files_to_copy:
+                tar.add(os.path.join(outdir, os.path.basename(additional)))
 
 
 class Uncertainty(object):
